# SizeViewer
Creates graphics and tables from ViewSizer 3000 .dat files for easy comparison of parameters and measurements.

![Example graphic](Example.png)

# How to use
1. Install Anaconda.
2. Create a new `conda` environment, then within it, install NumPy, SciPy, Pandas, and Matplotlib. (Future updates will include an importable `conda` environment.)
3. Open DifferencePlotter.py in a code editor and adjust the settings, beginning at line 28. (This will soon be replaced with a more user-friendly process.)
4. Run DifferencePlotter.py, which will output .csv files into a "CSV outputs" folder in its parent directory and display a graphic.
